@@ -23,7 +23,7 @@ pub fn app(cx: Scope) -> Element {
                     },
                     None => {},
                 }
-                console_log!(element_inner_html!(".main"));
+                console_log!(document_inner_html!(".main"));
                 console_log!(document_base_uri!());
 
                 // element_set_inner_html!(".main","<h1>hello</h1>")
